<template>
  <div>
    <el-dialog
      v-model="dialogVisible"
      :title="title"
      width="600"
      :close-on-click-modal="false"
      :before-close="handleClose"
    >
      <el-form
        ref="formRef"
        style="max-width: 400px; margin: 0 auto"
        :model="formData"
        :rules="rules"
        label-width="auto"
      >
        <el-form-item label="煤种类型" prop="coal">
          <el-input
            v-model="formData.coal"
            placeholder="请输入供货商名称"
          />
        </el-form-item>
        <el-form-item label="全水含量百分比 (%)" prop="totalMoisture">
          <el-input
            v-model="formData.totalMoisture"
            placeholder="请输入全水含量百分比"
          />
        </el-form-item>
        <el-form-item label="全水含量百分比 (%)" prop="analysisMoisture">
          <el-input
            v-model="formData.analysisMoisture"
            placeholder="请输入全水含量百分比"
          />
        </el-form-item>
        <el-form-item label="全水含量百分比 (%)" prop="volatileMatter">
          <el-input
            v-model="formData.volatileMatter"
            placeholder="请输入全水含量百分比"
          />
        </el-form-item>
        <el-form-item label="固定碳百分比 (%)" prop="fixedCarbon">
          <el-input
            v-model="formData.fixedCarbon"
            placeholder="请输入客户详细地址"
          />
        </el-form-item>
        <el-form-item label="低位发热量（单位：千卡/千克）" prop="lowerHeatValue">
          <el-input
            v-model="formData.lowerHeatValue"
            placeholder="请输入银行账户"
          />
        </el-form-item>
        <el-form-item label="高位发热量（单位：千卡/千克）" prop="higherHeatValue">
          <el-input v-model="formData.higherHeatValue" placeholder="请输入开户行" />
        </el-form-item>
        <el-form-item label="灰分百分比 (%)" prop="ashContent">
          <el-input v-model="formData.ashContent" placeholder="请输入联系人" />
        </el-form-item>
        <el-form-item label="硫含量百分比 (%)" prop="sulfurContent">
          <el-input
            v-model="formData.sulfurContent"
            placeholder="请输入联系人电话"
          />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" @click="submitForm"> 确定 </el-button>
          <el-button v-if="addOrEdit === 'edit'" @click="resetForm"
            >重置</el-button
          >
          <el-button v-if="addOrEdit === 'add'" @click="cancelForm"
            >取消</el-button
          >
        </el-form-item>
      </el-form>
    </el-dialog>
  </div>
</template>

<script setup>
import { ref, watch, defineProps, onMounted } from "vue";
import addressList from "@/api/jsonApi/areaList.json";
import { addOrEditCoalQuality } from "@/api/basicInformation/coalQualityMaintenance.js";
const props = defineProps({
  beforeClose: {
    type: Function,
    default: () => {},
  },
  form: {
    type: Object,
    default: () => ({}),
  },
  addOrEdit: {
    type: String,
    default: "add",
  },
  title: {
    type: String,
    default: "",
  },
});

const emit = defineEmits(["submit", "handleBeforeClose"]);

onMounted(()=>{
  addressSelectOptions.value = mapAddress(addressList);
})
// 地址选择数据
const addressSelectOptions = ref([]);
// 处理地址数据转换
function mapAddress(list) {
  return list.map(item => ({
    value: item.no,
    label: item.name,
    children: item.children ? mapAddress(item.children) : undefined
  }));
}
// 表单引用
const formRef = ref(null);
// 表单数据
const formData = ref({ ...props.form });
// 弹窗可见性
const dialogVisible = defineModel("coalQualityMaintenanceDialogFormVisible", {
  required: true,
  type: Boolean,
});
// 监听外部传入的表单数据变化
watch(
  () => props.form,
  (newVal) => {
    formData.value = { ...newVal };
  },
  { deep: true }
);

// 监听内部弹窗状态变化
watch(
  () => dialogVisible.value,
  (newVal) => {
    emit("update:coalQualityMaintenanceDialogFormVisible", newVal);
  }
);
// 处理地址选择变化
const handleChange = (value) => {
  console.log(value);
};
// 提交表单
const submitForm = async () => {
  if (!formRef.value) return;
  await formRef.value.validate(async (valid, fields) => {
    if (valid) {

      let result = await addOrEditCoalQuality({...formData.value});
      console.log(result);
      // emit("submit", formData.value);
    }
  });
};
// 取消表单
const cancelForm = () => {
  emit("update:coalQualityMaintenanceDialogFormVisible", false);
  formData.value = {};
};
// 重置表单
const resetForm = () => {
  if (!formRef.value) return;
  formRef.value.resetFields();
};
// 关闭弹窗
const handleClose = () => {
  // 触发父组件的关闭函数
  emit("handleBeforeClose");
  emit("update:coalQualityMaintenanceDialogFormVisible", false);
};
const rules = reactive({
  coal: [
    { required: true, message: "请输入煤种名称", trigger: "blur" },
  ],
});
</script>
<style lang="sass" scoped>
</style>